@@ -19,6 +19,7 @@ class Host:
             self.name = name
         self.username = kwargs.get("username", settings.HOST_USERNAME)
         self.password = kwargs.get("password", settings.HOST_PASSWORD)
+        self.timeout = kwargs.get("connection_timeout", settings.HOST_CONNECTION_TIMEOUT)
         self._session = None
 
     def __del__(self):
@@ -48,12 +49,13 @@ class Host:
             except (pickle.PicklingError, AttributeError):
                 self.__dict__[key] = None
 
-    def connect(self, username=None, password=None):
+    def connect(self, username=None, password=None, timeout=None):
         username = username or self.username
         password = password or self.password
+        timeout = timeout or self.timeout
         self.close()
         self._session = Session(
-            hostname=self.hostname, username=username, password=password
+            hostname=self.hostname, username=username, password=password, timeout=timeout
         )
 
     def close(self):
